;; Generated package description from yaml.el  -*- no-byte-compile: t -*-
(define-package "yaml" "1.0.0.0.20241129.211417" "YAML parser for Elisp" '((emacs "25.1")) :commit "cd3edfc02cb12514426c00e07160b87bd8340f4a" :authors '(("Zachary Romero" . "zkry@posteo.org")) :maintainer '("Zachary Romero" . "zkry@posteo.org") :keywords '("tools") :url "https://github.com/zkry/yaml.el")
